@@ -18,23 +18,38 @@ from cloud_governance.main.es_uploader import ESUploader
 # os.environ['policy'] = 'ec2_untag'
 #os.environ['policy'] = 'zombie_cluster_resource'
 # os.environ['policy'] = 'tag_cluster_resource'
-# os.environ['policy_output'] ='s3://redhat-cloud-governance/logs'
+#os.environ['policy_output'] ='s3://redhat-cloud-governance/logs'
+#os.environ['policy_output'] = os.path.dirname(os.path.realpath(__file__))
 #os.environ['dry_run'] = 'yes'
 # os.environ['policy'] = 'ebs_unattached'
 # os.environ['resource_name'] = 'ocp-orch-perf'
 # os.environ['resource_name'] = 'ocs-test'
 # os.environ['mandatory_tags'] = "{'Owner': 'Eli Battat','Email': 'ebattat@redhat.com','Purpose': 'test'}"
 # os.environ['mandatory_tags'] = ''
-# os.environ['policy'] = 'gitleaks'
-# os.environ['git_access_token'] = ''
-# os.environ['git_repo'] = 'https://github.com/redhat-performance/pulpperf'
+#os.environ['policy'] = 'gitleaks'
+#os.environ['git_access_token'] = ''
+#os.environ['git_repo'] = 'https://github.com/redhat-performance/pulpperf'
+#os.environ['git_repo'] = 'https://github.com/redhat-performance'
 # os.environ['git_repo'] = 'https://github.com/gitleakstest/gronit'
-# os.environ['several_repos'] = 'Yes'
+#os.environ['several_repos'] = 'Yes'
 # os.environ['upload_data_elk'] = 'upload_data_elk'
 
 log_level = os.environ.get('log_level', 'INFO').upper()
 logger.setLevel(level=log_level)
-custodian_policies = ['ec2_idle', 'ebs_unattached', 'ec2_untag']
+
+
+def get_custodian_policies():
+    """
+    This method return a list of policies name without extension
+    @return: list of custodian policies name
+    """
+    custodian_policies = []
+    # policies_path working only inside the docker
+    policies_path = os.path.join(os.path.dirname(__file__), 'policy')
+    for (dirpath, dirnames, filenames) in os.walk(policies_path):
+        for filename in filenames:
+            custodian_policies.append(os.path.splitext(filename)[0])
+    return custodian_policies
 
 
 @logger_time_stamp
@@ -75,19 +90,21 @@ def run_policy(policy: str, region: str, dry_run: str):
         git_access_token = os.environ.get('git_access_token')
         git_repo = os.environ.get('git_repo')
         several_repos = os.environ.get('several_repos')
+        policy_output = os.environ.get('policy_output', '')
         try:
-            if several_repos == 'Yes':
+            if several_repos == 'yes':
                 git_leaks = GitLeaks(git_access_token=git_access_token,
                                      git_repo=git_repo,
                                      several_repos=True)
             else:
                 git_leaks = GitLeaks(git_access_token=git_access_token,
                                      git_repo=git_repo)
-            logger.info(git_leaks.scan_repo())
+            logger.info(git_leaks.write_result(policy_output, region, policy))
+
         except Exception as err:
             logger.exception(f'BadCredentialsException : {err}')
     # custodian policy - check if its a custodian policy
-    elif any(policy == item for item in custodian_policies):
+    elif any(policy == item for item in get_custodian_policies()):
         # default is dry run - change it to custodian dry run format
         if dry_run == 'yes':
             dry_run = '--dryrun'
@@ -95,7 +112,8 @@ def run_policy(policy: str, region: str, dry_run: str):
             dry_run = ''
         else:  # default dry run
             dry_run = '--dryrun'
-        policy_output = os.environ['policy_output']
+        policy_output = os.environ.get('policy_output', '')
+        # policies_path working only inside the docker
         # run from local - policies_path = os.path.join(os.path.dirname(__file__), '../' ,f'{policy}.yml')
         policies_path = os.path.join(os.path.dirname(__file__), 'policy')
         if os.path.isfile(f'{policies_path}/{policy}.yml'):
@@ -111,7 +129,7 @@ def run_policy(policy: str, region: str, dry_run: str):
             dry_run = ''
         else:  # default dry run
             dry_run = '--dryrun'
-        policy_output = os.environ['policy_output']
+        policy_output = os.environ.get('policy_output', '')
         # run from local - policies_path = os.path.join(os.path.dirname(__file__), '../' ,f'{policy}.yml')
         if os.path.isfile(policy):
             os.system(f'custodian run {dry_run} -s {policy_output} {policy}')
@@ -129,7 +147,7 @@ def main():
     :return: the action output
     """
     # environment variables - get while running the docker
-    region_env = os.environ.get('AWS_DEFAULT_REGION', 'us-east-2')
+    region_env = os.environ.get('AWS_DEFAULT_REGION', 'us-east-1')
     dry_run = os.environ.get('dry_run', 'yes')
     policy = os.environ.get('policy', '')
     upload_data_es = os.environ.get('upload_data_es', '')
@@ -159,7 +177,7 @@ def main():
             raise Exception(f'Missing Policy name: "{policy}"')
             logger.exception(f'Missing Policy name: "{policy}"')
         if region_env == 'all':
-            # must be set for bot03 client default region
+            # must be set for boto3 client default region
             os.environ['AWS_DEFAULT_REGION'] = 'us-east-2'
             ec2 = boto3.client('ec2')
             regions_data = ec2.describe_regions()
@@ -172,4 +190,3 @@ def main():
 
 
 main()
-
